==> qtaf-http-0.2.1-sources.jar: de/qytera/qtaf/http/HTTPJsonDao.java <==
package de.qytera.qtaf.http;

import de.qytera.qtaf.core.gson.GsonHelper;
import jakarta.ws.rs.core.MediaType;

/**
 * A DAO for HTTP requests with JSON content.
 */
public class HTTPJsonDao extends HTTPDao {

    /**
     * Constructor
     *
     * @param host host name
     */
    public HTTPJsonDao(String host) {
        super(host);
    }

    /**
     * Send GET Request
     *
     * @param path   URL path
     * @param tClass Entity class
     * @param <T>    Entity Type
     * @return Entity object
     */
    public <T> T get(String path, Class<T> tClass) {
        String json = super.getAsString(path, MediaType.APPLICATION_JSON);
        return GsonHelper.fromJson(json, tClass);
    }

    /**
     * Send POST Request
     *
     * @param path          URL path
     * @param tClass        Entity class
     * @param <T>           Entity Type
     * @param requestEntity Request payload
     * @return Entity object
     */
    public <T> T post(String path, Class<T> tClass, Object requestEntity) {
        String json = super.postAsString(path, MediaType.APPLICATION_JSON, gson.toJson(requestEntity));
        return GsonHelper.fromJson(json, tClass);
    }

    /**
     * Send PUT Request
     *
     * @param path          URL path
     * @param tClass        Entity class
     * @param <T>           Entity Type
     * @param requestEntity Request payload
     * @return Entity object
     */
    public <T> T put(String path, Class<T> tClass, Object requestEntity) {
        String json = super.putAsString(path, MediaType.APPLICATION_JSON, gson.toJson(requestEntity));
        return GsonHelper.fromJson(json, tClass);
    }

    /**
     * Send DELETE Request
     *
     * @param path   URL path
     * @param tClass Entity class
     * @param <T>    Entity Type
     * @return Entity object
     */
    public <T> T delete(String path, Class<T> tClass) {
        String json = super.deleteAsString(path, MediaType.APPLICATION_JSON);
        return GsonHelper.fromJson(json, tClass);
    }

}

==> qtaf-http-0.2.14-sources.jar: de/qytera/qtaf/http/HTTPJsonDao.java <==
package de.qytera.qtaf.http;

import de.qytera.qtaf.core.gson.GsonHelper;
import jakarta.ws.rs.core.MediaType;

/**
 * A DAO for HTTP requests with JSON content.
 */
public class HTTPJsonDao extends HTTPDao {

    /**
     * Constructor.
     *
     * @param host host name
     */
    public HTTPJsonDao(String host) {
        super(host);
    }

    /**
     * Send GET Request.
     *
     * @param path   URL path
     * @param tClass Entity class
     * @param <T>    Entity Type
     * @return Entity object
     */
    public <T> T get(String path, Class<T> tClass) {
        String json = super.getAsString(path, MediaType.APPLICATION_JSON);
        return GsonHelper.fromJson(json, tClass);
    }

    /**
     * Send POST Request.
     *
     * @param path          URL path
     * @param tClass        Entity class
     * @param <T>           Entity Type
     * @param requestEntity Request payload
     * @return Entity object
     */
    public <T> T post(String path, Class<T> tClass, Object requestEntity) {
        String json = super.postAsString(path, MediaType.APPLICATION_JSON, gson.toJson(requestEntity));
        return GsonHelper.fromJson(json, tClass);
    }

    /**
     * Send PUT Request.
     *
     * @param path          URL path
     * @param tClass        Entity class
     * @param <T>           Entity Type
     * @param requestEntity Request payload
     * @return Entity object
     */
    public <T> T put(String path, Class<T> tClass, Object requestEntity) {
        String json = super.putAsString(path, MediaType.APPLICATION_JSON, gson.toJson(requestEntity));
        return GsonHelper.fromJson(json, tClass);
    }

    /**
     * Send DELETE Request.
     *
     * @param path   URL path
     * @param tClass Entity class
     * @param <T>    Entity Type
     * @return Entity object
     */
    public <T> T delete(String path, Class<T> tClass) {
        String json = super.deleteAsString(path, MediaType.APPLICATION_JSON);
        return GsonHelper.fromJson(json, tClass);
    }

}
